.. _installation:

Installation
============

So, you want to try **Sphinxit**? Good! Installation is simple as always with ``pip``::

    $ pip install sphinxit


Do it in your project`s virtualenv... you know. Or, you can grab 
`latest code from Github <https://github.com/semirook/sphinxit>`_. Just::

    $ pip install -e git+https://github.com/semirook/sphinxit#egg=sphinxit


The only dependencies of Sphinxit are ``oursql`` (MySQL layer) and ``six`` (Python 2 and 3 compatibility layer)
libraries. And, of course, SphinxSearch itself.

What`s next? Visit :ref:`quickstart` to learn more.